@@ -1,6 +1,7 @@
 package Pithub::GitData::Commits;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Git Data Commits API
 
 use Moo;
@@ -10,11 +11,14 @@ extends 'Pithub::Base';
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/git/commits', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/git/commits', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -26,7 +30,10 @@ sub get {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/git/commits/%s', delete $args{user}, delete $args{repo}, delete $args{sha} ),
+        path   => sprintf(
+            '/repos/%s/%s/git/commits/%s', delete $args{user},
+            delete $args{repo},            delete $args{sha}
+        ),
         %args,
     );
 }
@@ -45,7 +52,7 @@ Pithub::GitData::Commits - Github v3 Git Data Commits API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
