@@ -1,6 +1,7 @@
 package Pithub::GitData::Trees;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Git Data Trees API
 
 use Moo;
@@ -10,11 +11,14 @@ extends 'Pithub::Base';
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/git/trees', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/git/trees', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -24,7 +28,10 @@ sub get {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: sha' unless $args{sha};
     $self->_validate_user_repo_args( \%args );
-    my $path = sprintf( '/repos/%s/%s/git/trees/%s', $args{user}, $args{repo}, $args{sha} );
+    my $path = sprintf(
+        '/repos/%s/%s/git/trees/%s', $args{user}, $args{repo},
+        $args{sha}
+    );
     my %params = ();
     if ( $args{recursive} ) {
         $params{recursive} = 1;
@@ -51,7 +58,7 @@ Pithub::GitData::Trees - Github v3 Git Data Trees API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
