@@ -1,42 +1,46 @@
 package Pithub::Issues;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Issues API
 
 use Moo;
-use Carp qw( croak );
-use Pithub::Issues::Assignees;
-use Pithub::Issues::Comments;
-use Pithub::Issues::Events;
-use Pithub::Issues::Labels;
-use Pithub::Issues::Milestones;
+use Carp                       qw( croak );
+use Pithub::Issues::Assignees  ();
+use Pithub::Issues::Comments   ();
+use Pithub::Issues::Events     ();
+use Pithub::Issues::Labels     ();
+use Pithub::Issues::Milestones ();
 extends 'Pithub::Base';
 
 
 sub assignees {
-    return shift->_create_instance('Pithub::Issues::Assignees', @_);
+    return shift->_create_instance( Pithub::Issues::Assignees::, @_ );
 }
 
 
 sub comments {
-    return shift->_create_instance('Pithub::Issues::Comments', @_);
+    return shift->_create_instance( Pithub::Issues::Comments::, @_ );
 }
 
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/issues', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/issues', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
 
 
 sub events {
-    return shift->_create_instance('Pithub::Issues::Events', @_);
+    return shift->_create_instance( Pithub::Issues::Events::, @_ );
 }
 
 
@@ -46,14 +50,17 @@ sub get {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/issues/%s', delete $args{user}, delete $args{repo}, delete $args{issue_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/issues/%s', delete $args{user}, delete $args{repo},
+            delete $args{issue_id}
+        ),
         %args,
     );
 }
 
 
 sub labels {
-    return shift->_create_instance('Pithub::Issues::Labels', @_);
+    return shift->_create_instance( Pithub::Issues::Labels::, @_ );
 }
 
 
@@ -63,7 +70,9 @@ sub list {
     if ( $args{user} && $args{repo} ) {
         return $self->request(
             method => 'GET',
-            path   => sprintf( '/repos/%s/%s/issues', delete $args{user}, delete $args{repo} ),
+            path   => sprintf(
+                '/repos/%s/%s/issues', delete $args{user}, delete $args{repo}
+            ),
             %args,
         );
     }
@@ -76,18 +85,22 @@ sub list {
 
 
 sub milestones {
-    return shift->_create_instance('Pithub::Issues::Milestones', @_);
+    return shift->_create_instance( Pithub::Issues::Milestones::, @_ );
 }
 
 
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: issue_id' unless $args{issue_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PATCH',
-        path   => sprintf( '/repos/%s/%s/issues/%s', delete $args{user}, delete $args{repo}, delete $args{issue_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/issues/%s', delete $args{user}, delete $args{repo},
+            delete $args{issue_id}
+        ),
         %args,
     );
 }
@@ -106,7 +119,7 @@ Pithub::Issues - Github v3 Issues API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
