@@ -1,6 +1,7 @@
 package Pithub::Issues::Assignees;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Issue Assignees API
 
 use Moo;
@@ -14,7 +15,10 @@ sub check {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/assignees/%s', delete $args{user}, delete $args{repo}, delete $args{assignee} ),
+        path   => sprintf(
+            '/repos/%s/%s/assignees/%s', delete $args{user},
+            delete $args{repo},          delete $args{assignee}
+        ),
         %args,
     );
 }
@@ -25,7 +29,9 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/assignees', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/assignees', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -44,7 +50,7 @@ Pithub::Issues::Assignees - Github v3 Issue Assignees API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
