@@ -1,6 +1,7 @@
 package Pithub::Issues::Labels;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Issue Labels API
 
 use Moo;
@@ -11,11 +12,15 @@ extends 'Pithub::Base';
 sub add {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: issue_id' unless $args{issue_id};
-    croak 'Missing key in parameters: data (arrayref)' unless ref $args{data} eq 'ARRAY';
+    croak 'Missing key in parameters: data (arrayref)'
+        unless ref $args{data} eq 'ARRAY';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/issues/%s/labels', delete $args{user}, delete $args{repo}, delete $args{issue_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/issues/%s/labels', delete $args{user},
+            delete $args{repo},              delete $args{issue_id}
+        ),
         %args,
     );
 }
@@ -23,11 +28,14 @@ sub add {
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/labels', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/labels', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -39,7 +47,10 @@ sub delete {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/repos/%s/%s/labels/%s', delete $args{user}, delete $args{repo}, delete $args{label} ),
+        path   => sprintf(
+            '/repos/%s/%s/labels/%s', delete $args{user}, delete $args{repo},
+            delete $args{label}
+        ),
         %args,
     );
 }
@@ -51,7 +62,10 @@ sub get {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/labels/%s', delete $args{user}, delete $args{repo}, delete $args{label} ),
+        path   => sprintf(
+            '/repos/%s/%s/labels/%s', delete $args{user}, delete $args{repo},
+            delete $args{label}
+        ),
         %args,
     );
 }
@@ -63,20 +77,28 @@ sub list {
     if ( my $milestone_id = delete $args{milestone_id} ) {
         return $self->request(
             method => 'GET',
-            path   => sprintf( '/repos/%s/%s/milestones/%s/labels', delete $args{user}, delete $args{repo}, $milestone_id ),
+            path   => sprintf(
+                '/repos/%s/%s/milestones/%s/labels', delete $args{user},
+                delete $args{repo},                  $milestone_id
+            ),
             %args,
         );
     }
     elsif ( my $issue_id = delete $args{issue_id} ) {
         return $self->request(
             method => 'GET',
-            path   => sprintf( '/repos/%s/%s/issues/%s/labels', delete $args{user}, delete $args{repo}, $issue_id ),
+            path   => sprintf(
+                '/repos/%s/%s/issues/%s/labels', delete $args{user},
+                delete $args{repo},              $issue_id
+            ),
             %args
         );
     }
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/labels', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/labels', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -89,13 +111,19 @@ sub remove {
     if ( my $label = delete $args{label} ) {
         return $self->request(
             method => 'DELETE',
-            path   => sprintf( '/repos/%s/%s/issues/%s/labels/%s', delete $args{user}, delete $args{repo}, delete $args{issue_id}, $label ),
+            path   => sprintf(
+                '/repos/%s/%s/issues/%s/labels/%s', delete $args{user},
+                delete $args{repo}, delete $args{issue_id}, $label
+            ),
             %args,
         );
     }
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/repos/%s/%s/issues/%s/labels', delete $args{user}, delete $args{repo}, delete $args{issue_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/issues/%s/labels', delete $args{user},
+            delete $args{repo},              delete $args{issue_id}
+        ),
         %args,
     );
 }
@@ -104,11 +132,15 @@ sub remove {
 sub replace {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: issue_id' unless $args{issue_id};
-    croak 'Missing key in parameters: data (arrayref)' unless ref $args{data} eq 'ARRAY';
+    croak 'Missing key in parameters: data (arrayref)'
+        unless ref $args{data} eq 'ARRAY';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/repos/%s/%s/issues/%s/labels', delete $args{user}, delete $args{repo}, delete $args{issue_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/issues/%s/labels', delete $args{user},
+            delete $args{repo},              delete $args{issue_id}
+        ),
         %args,
     );
 }
@@ -117,11 +149,15 @@ sub replace {
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: label' unless $args{label};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PATCH',
-        path   => sprintf( '/repos/%s/%s/labels/%s', delete $args{user}, delete $args{repo}, delete $args{label} ),
+        path   => sprintf(
+            '/repos/%s/%s/labels/%s', delete $args{user}, delete $args{repo},
+            delete $args{label}
+        ),
         %args,
     );
 }
@@ -140,7 +176,7 @@ Pithub::Issues::Labels - Github v3 Issue Labels API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
