@@ -1,6 +1,7 @@
 package Pithub::Orgs::Members;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Org Members API
 
 use Moo;
@@ -14,7 +15,10 @@ sub conceal {
     croak 'Missing key in parameters: user' unless $args{user};
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/orgs/%s/public_members/%s', delete $args{org}, delete $args{user} ),
+        path   => sprintf(
+            '/orgs/%s/public_members/%s', delete $args{org},
+            delete $args{user}
+        ),
         %args,
     );
 }
@@ -26,7 +30,9 @@ sub delete {
     croak 'Missing key in parameters: user' unless $args{user};
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/orgs/%s/members/%s', delete $args{org}, delete $args{user} ),
+        path   => sprintf(
+            '/orgs/%s/members/%s', delete $args{org}, delete $args{user}
+        ),
         %args,
     );
 }
@@ -38,7 +44,9 @@ sub is_member {
     croak 'Missing key in parameters: user' unless $args{user};
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/orgs/%s/members/%s', delete $args{org}, delete $args{user} ),
+        path   => sprintf(
+            '/orgs/%s/members/%s', delete $args{org}, delete $args{user}
+        ),
         %args,
     );
 }
@@ -50,7 +58,10 @@ sub is_public {
     croak 'Missing key in parameters: user' unless $args{user};
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/orgs/%s/public_members/%s', delete $args{org}, delete $args{user} ),
+        path   => sprintf(
+            '/orgs/%s/public_members/%s', delete $args{org},
+            delete $args{user}
+        ),
         %args,
     );
 }
@@ -84,7 +95,10 @@ sub publicize {
     croak 'Missing key in parameters: user' unless $args{user};
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/orgs/%s/public_members/%s', delete $args{org}, delete $args{user} ),
+        path   => sprintf(
+            '/orgs/%s/public_members/%s', delete $args{org},
+            delete $args{user}
+        ),
         %args,
     );
 }
@@ -103,7 +117,7 @@ Pithub::Orgs::Members - Github v3 Org Members API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
