@@ -1,10 +1,11 @@
 package Pithub::Orgs::Teams;
 our $AUTHORITY = 'cpan:PLU';
+
 # ABSTRACT: Github v3 Org Teams API
 
 use Moo;
 
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
 
 use Carp qw( carp croak );
 
@@ -18,7 +19,9 @@ sub add_member {
     carp q{"Add team member" API is deprecated. Use add_membership method.};
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/teams/%s/members/%s', delete $args{team_id}, delete $args{user} ),
+        path   => sprintf(
+            '/teams/%s/members/%s', delete $args{team_id}, delete $args{user}
+        ),
         %args,
     );
 }
@@ -31,7 +34,10 @@ sub add_membership {
     croak 'Missing key in parameters: data'    unless $args{data};
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/teams/%s/memberships/%s', delete $args{team_id}, delete $args{user} ),
+        path   => sprintf(
+            '/teams/%s/memberships/%s', delete $args{team_id},
+            delete $args{user}
+        ),
         %args,
     );
 }
@@ -44,10 +50,12 @@ sub add_repo {
     croak 'Missing key in parameters: org'     unless $args{org};
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/teams/%s/repos/%s/%s',
+        path   => sprintf(
+            '/teams/%s/repos/%s/%s',
             delete $args{team_id},
             delete $args{org},
-            delete $args{repo} ),
+            delete $args{repo}
+        ),
         %args,
     );
 }
@@ -56,7 +64,8 @@ sub add_repo {
 sub create {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: org' unless $args{org};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     return $self->request(
         method => 'POST',
         path   => sprintf( '/orgs/%s/teams', delete $args{org} ),
@@ -95,7 +104,9 @@ sub has_repo {
     croak 'Missing key in parameters: repo'    unless $args{repo};
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/teams/%s/repos/%s', delete $args{team_id}, delete $args{repo} ),
+        path   => sprintf(
+            '/teams/%s/repos/%s', delete $args{team_id}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -107,7 +118,9 @@ sub is_member {
     croak 'Missing key in parameters: user'    unless $args{user};
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/teams/%s/members/%s', delete $args{team_id}, delete $args{user} ),
+        path   => sprintf(
+            '/teams/%s/members/%s', delete $args{team_id}, delete $args{user}
+        ),
         %args,
     );
 }
@@ -150,10 +163,13 @@ sub remove_member {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
     croak 'Missing key in parameters: user'    unless $args{user};
-    carp q{"Remove team member" API is deprecated. Use remove_membership method.};
+    carp
+        q{"Remove team member" API is deprecated. Use remove_membership method.};
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/teams/%s/members/%s', delete $args{team_id}, delete $args{user} ),
+        path   => sprintf(
+            '/teams/%s/members/%s', delete $args{team_id}, delete $args{user}
+        ),
         %args,
     );
 }
@@ -165,7 +181,10 @@ sub remove_membership {
     croak 'Missing key in parameters: user'    unless $args{user};
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/teams/%s/memberships/%s', delete $args{team_id}, delete $args{user} ),
+        path   => sprintf(
+            '/teams/%s/memberships/%s', delete $args{team_id},
+            delete $args{user}
+        ),
         %args,
     );
 }
@@ -177,7 +196,9 @@ sub remove_repo {
     croak 'Missing key in parameters: repo'    unless $args{repo};
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/teams/%s/repos/%s', delete $args{team_id}, delete $args{repo} ),
+        path   => sprintf(
+            '/teams/%s/repos/%s', delete $args{team_id}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -186,7 +207,8 @@ sub remove_repo {
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: team_id' unless $args{team_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     return $self->request(
         method => 'PATCH',
         path   => sprintf( '/teams/%s', delete $args{team_id} ),
@@ -208,7 +230,7 @@ Pithub::Orgs::Teams - Github v3 Org Teams API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
