@@ -1,32 +1,37 @@
 package Pithub::PullRequests;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Pull Requests API
 
 use Moo;
-use Carp qw( croak );
-use Pithub::PullRequests::Comments;
-use Pithub::PullRequests::Reviewers;
+use Carp                            qw( croak );
+use Pithub::PullRequests::Comments  ();
+use Pithub::PullRequests::Reviewers ();
 extends 'Pithub::Base';
 
 
 sub comments {
-    return shift->_create_instance('Pithub::PullRequests::Comments', @_);
+    return shift->_create_instance( Pithub::PullRequests::Comments::, @_ );
 }
 
 
 sub reviewers {
-    return shift->_create_instance('Pithub::PullRequests::Reviewers', @_);
+    return shift->_create_instance( Pithub::PullRequests::Reviewers::, @_ );
 }
 
 
 sub commits {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/pulls/%s/commits', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s/commits', delete $args{user},
+            delete $args{repo},              delete $args{pull_request_id}
+        ),
         %args,
     );
 }
@@ -34,11 +39,14 @@ sub commits {
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/pulls', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -46,11 +54,15 @@ sub create {
 
 sub files {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/pulls/%s/files', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s/files', delete $args{user},
+            delete $args{repo},            delete $args{pull_request_id}
+        ),
         %args,
     );
 }
@@ -58,11 +70,15 @@ sub files {
 
 sub get {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/pulls/%s', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s', delete $args{user}, delete $args{repo},
+            delete $args{pull_request_id}
+        ),
         %args,
     );
 }
@@ -70,11 +86,15 @@ sub get {
 
 sub is_merged {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/pulls/%s/merge', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s/merge', delete $args{user},
+            delete $args{repo},            delete $args{pull_request_id}
+        ),
         %args,
     );
 }
@@ -85,7 +105,9 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/pulls', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -93,11 +115,15 @@ sub list {
 
 sub merge {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/repos/%s/%s/pulls/%s/merge', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s/merge', delete $args{user},
+            delete $args{repo},            delete $args{pull_request_id}
+        ),
         %args,
     );
 }
@@ -105,12 +131,17 @@ sub merge {
 
 sub update {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PATCH',
-        path   => sprintf( '/repos/%s/%s/pulls/%s', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s', delete $args{user}, delete $args{repo},
+            delete $args{pull_request_id}
+        ),
         %args,
     );
 }
@@ -129,7 +160,7 @@ Pithub::PullRequests - Github v3 Pull Requests API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
