@@ -1,6 +1,7 @@
 package Pithub::PullRequests::Comments;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Pull Request Comments API
 
 use Moo;
@@ -10,12 +11,17 @@ extends 'Pithub::Base';
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/pulls/%s/comments', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s/comments', delete $args{user},
+            delete $args{repo},               delete $args{pull_request_id}
+        ),
         %args
     );
 }
@@ -27,7 +33,10 @@ sub delete {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/repos/%s/%s/pulls/comments/%s', delete $args{user}, delete $args{repo}, delete $args{comment_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/comments/%s', delete $args{user},
+            delete $args{repo},               delete $args{comment_id}
+        ),
         %args,
     );
 }
@@ -39,7 +48,10 @@ sub get {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/pulls/comments/%s', delete $args{user}, delete $args{repo}, delete $args{comment_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/comments/%s', delete $args{user},
+            delete $args{repo},               delete $args{comment_id}
+        ),
         %args,
     );
 }
@@ -47,11 +59,15 @@ sub get {
 
 sub list {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: pull_request_id' unless $args{pull_request_id};
+    croak 'Missing key in parameters: pull_request_id'
+        unless $args{pull_request_id};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/pulls/%s/comments', delete $args{user}, delete $args{repo}, delete $args{pull_request_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/%s/comments', delete $args{user},
+            delete $args{repo},               delete $args{pull_request_id}
+        ),
         %args,
     );
 }
@@ -60,11 +76,15 @@ sub list {
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: comment_id' unless $args{comment_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PATCH',
-        path   => sprintf( '/repos/%s/%s/pulls/comments/%s', delete $args{user}, delete $args{repo}, delete $args{comment_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/pulls/comments/%s', delete $args{user},
+            delete $args{repo},               delete $args{comment_id}
+        ),
         %args,
     );
 }
@@ -83,7 +103,7 @@ Pithub::PullRequests::Comments - Github v3 Pull Request Comments API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
