@@ -1,6 +1,7 @@
 package Pithub::Repos::Collaborators;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Repo Collaborators API
 
 use Moo;
@@ -10,11 +11,15 @@ extends 'Pithub::Base';
 
 sub add {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
+    croak 'Missing key in parameters: collaborator'
+        unless $args{collaborator};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/repos/%s/%s/collaborators/%s', delete $args{user}, delete $args{repo}, delete $args{collaborator} ),
+        path   => sprintf(
+            '/repos/%s/%s/collaborators/%s', delete $args{user},
+            delete $args{repo},              delete $args{collaborator}
+        ),
         %args,
     );
 }
@@ -22,11 +27,15 @@ sub add {
 
 sub is_collaborator {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
+    croak 'Missing key in parameters: collaborator'
+        unless $args{collaborator};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/collaborators/%s', delete $args{user}, delete $args{repo}, delete $args{collaborator} ),
+        path   => sprintf(
+            '/repos/%s/%s/collaborators/%s', delete $args{user},
+            delete $args{repo},              delete $args{collaborator}
+        ),
         %args,
     );
 }
@@ -37,7 +46,10 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/collaborators', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/collaborators', delete $args{user},
+            delete $args{repo}
+        ),
         %args,
     );
 }
@@ -45,11 +57,15 @@ sub list {
 
 sub remove {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: collaborator' unless $args{collaborator};
+    croak 'Missing key in parameters: collaborator'
+        unless $args{collaborator};
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/repos/%s/%s/collaborators/%s', delete $args{user}, delete $args{repo}, delete $args{collaborator} ),
+        path   => sprintf(
+            '/repos/%s/%s/collaborators/%s', delete $args{user},
+            delete $args{repo},              delete $args{collaborator}
+        ),
         %args
     );
 }
@@ -68,7 +84,7 @@ Pithub::Repos::Collaborators - Github v3 Repo Collaborators API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
