@@ -1,21 +1,25 @@
 package Pithub::Repos::Downloads;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01039';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Repo Downloads API
 
 use Moo;
-use Carp qw( croak );
+use Carp                  qw( croak );
 use HTTP::Request::Common qw( POST );
 extends 'Pithub::Base';
 
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/downloads', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/downloads', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -27,7 +31,10 @@ sub delete {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/repos/%s/%s/downloads/%s', delete $args{user}, delete $args{repo}, delete $args{download_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/downloads/%s', delete $args{user},
+            delete $args{repo},          delete $args{download_id}
+        ),
         %args,
     );
 }
@@ -39,7 +46,10 @@ sub get {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/downloads/%s', delete $args{user}, delete $args{repo}, delete $args{download_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/downloads/%s', delete $args{user},
+            delete $args{repo},          delete $args{download_id}
+        ),
         %args,
     );
 }
@@ -50,7 +60,9 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/downloads', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/downloads', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -58,11 +70,14 @@ sub list {
 
 sub upload {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: result (Pithub::Result object)' unless ref $args{result} eq 'Pithub::Result';
+    croak 'Missing key in parameters: result (Pithub::Result object)'
+        unless ref $args{result} eq 'Pithub::Result';
     croak 'Missing key in parameters: file' unless $args{file};
     my $result = $args{result}->content;
-    foreach my $key (qw(path acl name accesskeyid policy signature mime_type)) {
-        croak "Missing key in Pithub::Result content: ${key}" unless grep $_ eq $key, keys %$result;
+    foreach
+        my $key (qw(path acl name accesskeyid policy signature mime_type)) {
+        croak "Missing key in Pithub::Result content: ${key}"
+            unless grep $_ eq $key, keys %$result;
     }
     my %data = (
         Content_Type => 'form-data',
@@ -96,7 +111,7 @@ Pithub::Repos::Downloads - Github v3 Repo Downloads API
 
 =head1 VERSION
 
-version 0.01039
+version 0.01041
 
 =head1 METHODS
 
