@@ -1,10 +1,10 @@
 package Pithub::Repos::Forks;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Repo Forks API
 
 use Moo;
-use Carp ();
 extends 'Pithub::Base';
 
 
@@ -14,14 +14,18 @@ sub create {
     if ( my $org = delete $args{org} ) {
         return $self->request(
             method => 'POST',
-            path   => sprintf( '/repos/%s/%s/forks', delete $args{user}, delete $args{repo} ),
+            path   => sprintf(
+                '/repos/%s/%s/forks', delete $args{user}, delete $args{repo}
+            ),
             data => { organization => $org },
             %args,
         );
     }
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/forks', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/forks', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -32,7 +36,9 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/forks', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/forks', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -51,7 +57,7 @@ Pithub::Repos::Forks - Github v3 Repo Forks API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
