@@ -1,6 +1,7 @@
 package Pithub::Repos::Hooks;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01039';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Repo Hooks API
 
 use Moo;
@@ -10,11 +11,14 @@ extends 'Pithub::Base';
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/hooks', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/hooks', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -26,7 +30,10 @@ sub delete {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/repos/%s/%s/hooks/%d', delete $args{user}, delete $args{repo}, delete $args{hook_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/hooks/%d', delete $args{user}, delete $args{repo},
+            delete $args{hook_id}
+        ),
         %args,
     );
 }
@@ -38,7 +45,10 @@ sub get {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/hooks/%d', delete $args{user}, delete $args{repo}, delete $args{hook_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/hooks/%d', delete $args{user}, delete $args{repo},
+            delete $args{hook_id}
+        ),
         %args,
     );
 }
@@ -49,7 +59,9 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/hooks', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/hooks', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -61,7 +73,10 @@ sub test {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/hooks/%d/test', delete $args{user}, delete $args{repo}, delete $args{hook_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/hooks/%d/test', delete $args{user},
+            delete $args{repo},           delete $args{hook_id}
+        ),
         %args,
     );
 }
@@ -70,11 +85,15 @@ sub test {
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: hook_id' unless $args{hook_id};
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PATCH',
-        path   => sprintf( '/repos/%s/%s/hooks/%d', delete $args{user}, delete $args{repo}, delete $args{hook_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/hooks/%d', delete $args{user}, delete $args{repo},
+            delete $args{hook_id}
+        ),
         %args,
     );
 }
@@ -93,7 +112,7 @@ Pithub::Repos::Hooks - Github v3 Repo Hooks API
 
 =head1 VERSION
 
-version 0.01039
+version 0.01041
 
 =head1 METHODS
 
@@ -283,7 +302,7 @@ public - Any time a Repository changes from private to public.
 
 =item *
 
-pull_request - Any time a Pull Request is opend, closed, or
+pull_request - Any time a Pull Request is opened, closed, or
 synchronized (updated due to a new push in the branch that
 the pull request is tracking).
 
