@@ -1,6 +1,7 @@
 package Pithub::Repos::Keys;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Repo Keys API
 
 use Moo;
@@ -10,11 +11,14 @@ extends 'Pithub::Base';
 
 sub create {
     my ( $self, %args ) = @_;
-    croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
+    croak 'Missing key in parameters: data (hashref)'
+        unless ref $args{data} eq 'HASH';
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'POST',
-        path   => sprintf( '/repos/%s/%s/keys', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/keys', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -26,7 +30,10 @@ sub delete {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/repos/%s/%s/keys/%s', delete $args{user}, delete $args{repo}, delete $args{key_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/keys/%s', delete $args{user}, delete $args{repo},
+            delete $args{key_id}
+        ),
         %args,
     );
 }
@@ -38,7 +45,10 @@ sub get {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/keys/%s', delete $args{user}, delete $args{repo}, delete $args{key_id} ),
+        path   => sprintf(
+            '/repos/%s/%s/keys/%s', delete $args{user}, delete $args{repo},
+            delete $args{key_id}
+        ),
         %args,
     );
 }
@@ -49,7 +59,9 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/keys', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/keys', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -68,7 +80,7 @@ Pithub::Repos::Keys - Github v3 Repo Keys API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
