@@ -1,6 +1,7 @@
 package Pithub::Repos::Stats;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 repos / stats API
 
 use Moo;
@@ -10,23 +11,22 @@ extends 'Pithub::Base';
 
 sub contributors {
     my ( $self, %args ) = @_;
+
     # The default is to not wait for 200
     my $sleep = delete $args{wait_for_200} || 0;
     $self->_validate_user_repo_args( \%args );
     my $req = {
         method => 'GET',
-        path => sprintf(
+        path   => sprintf(
             '/repos/%s/%s/stats/contributors',
             delete $args{user}, delete $args{repo}
         ),
         %args
     };
-    my $res = $self->request(
-        %$req
-    );
+    my $res = $self->request(%$req);
 
     if ($sleep) {
-        while ($res->response->code == 202) {
+        while ( $res->response->code == 202 ) {
             sleep $sleep;
             $res = $self->request(%$req);
         }
@@ -34,8 +34,6 @@ sub contributors {
     return $res;
 }
 
-
-
 1;
 
 __END__
@@ -50,7 +48,7 @@ Pithub::Repos::Stats - Github v3 repos / stats API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
