@@ -1,10 +1,10 @@
 package Pithub::Repos::Watching;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github v3 Repo Watching API
 
 use Moo;
-use Carp ();
 extends 'Pithub::Base';
 
 
@@ -13,7 +13,9 @@ sub is_watching {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/user/watched/%s/%s', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/user/watched/%s/%s', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -41,7 +43,9 @@ sub list {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/repos/%s/%s/watchers', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/repos/%s/%s/watchers', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -52,7 +56,9 @@ sub start_watching {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'PUT',
-        path   => sprintf( '/user/watched/%s/%s', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/user/watched/%s/%s', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -63,7 +69,9 @@ sub stop_watching {
     $self->_validate_user_repo_args( \%args );
     return $self->request(
         method => 'DELETE',
-        path   => sprintf( '/user/watched/%s/%s', delete $args{user}, delete $args{repo} ),
+        path   => sprintf(
+            '/user/watched/%s/%s', delete $args{user}, delete $args{repo}
+        ),
         %args,
     );
 }
@@ -82,7 +90,7 @@ Pithub::Repos::Watching - Github v3 Repo Watching API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
