@@ -1,6 +1,7 @@
 package Pithub::Search;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01040';
+our $VERSION = '0.01041';
+
 # ABSTRACT: Github legacy Search API
 
 use Moo;
@@ -22,11 +23,14 @@ sub email {
 sub issues {
     my ( $self, %args ) = @_;
     $self->_validate_user_repo_args( \%args );
-    croak 'Missing key in parameters: state' unless $args{state};
+    croak 'Missing key in parameters: state'   unless $args{state};
     croak 'Missing key in parameters: keyword' unless $args{keyword};
     return $self->request(
         method => 'GET',
-        path   => sprintf( '/legacy/issues/search/%s/%s/%s/%s', delete $args{user}, delete $args{repo}, delete $args{state}, delete $args{keyword} ),
+        path   => sprintf(
+            '/legacy/issues/search/%s/%s/%s/%s', delete $args{user},
+            delete $args{repo}, delete $args{state}, delete $args{keyword}
+        ),
         %args,
     );
 }
@@ -67,7 +71,7 @@ Pithub::Search - Github legacy Search API
 
 =head1 VERSION
 
-version 0.01040
+version 0.01041
 
 =head1 METHODS
 
